@@ -33,6 +33,7 @@
 
 HtmlDocument *document;
 HtmlParser *parser;
+GtkWidget *view;
 
 typedef struct {
 	gchar *title;
@@ -214,7 +215,9 @@ load_file (const gchar *filename)
 		
 	memset (buffer, 0, sizeof (buffer));
 	
+	html_view_set_document (HTML_VIEW (view), NULL);
 	html_document_clear (document);
+	html_view_set_document (HTML_VIEW (view), document);
 	
 	file = fopen (path, "r");
 	g_free (path);
@@ -311,7 +314,9 @@ cb_delete_event (GtkWidget *widget, gpointer data)
 static gboolean
 cb_clear_doc (GtkWidget *widget, gpointer data)
 {
+	html_view_set_document (HTML_VIEW (view), NULL);
   	html_document_clear (document);
+	html_view_set_document (HTML_VIEW (view), document);
 
 	return FALSE;
 }
@@ -401,7 +406,7 @@ gint
 main (gint argc, gchar **argv)
 {
 	GtkWidget *window;
-	GtkWidget *view, *frame;
+	GtkWidget *frame;
 	GtkWidget *tree_view;
 	GtkWidget *vbox, *hbox;
 	GtkWidget *hpaned, *button, *sw;
